@@ -106,6 +106,7 @@ def validateArgs(self, method, objectRequest, expecteObjectClass):
 
 @Function
 def handleLogErrorException(exception, resourceInstance, resourceInstanceMethod, context, apiInstance = None) :
+    apiInstance.repository.backupContext()
     try :
         exception = getGeneralGlobalException(exception, resourceInstance, resourceInstanceMethod, context, apiInstance = None)
         if ObjectHelper.isNone(apiInstance):
@@ -131,6 +132,7 @@ def handleLogErrorException(exception, resourceInstance, resourceInstanceMethod,
         apiInstance.repository.saveAndCommit(httpErrorLog)
     except Exception as errorLogException :
         log.warning(handleLogErrorException, f'Failed to persist {ErrorLog.ErrorLog.__name__}', exception=errorLogException)
+    apiInstance.repository.reloadContextBackup()
     return exception
 
 
